////////////////////////////////////////////////////////////////////////
// schedule.cpp
// generated with ecppc
//

#include <tnt/ecpp.h>
#include <tnt/convert.h>
#include <tnt/httprequest.h>
#include <tnt/httpreply.h>
#include <tnt/httpheader.h>
#include <tnt/http.h>
#include <tnt/data.h>
#include <tnt/componentfactory.h>
#include <cxxtools/log.h>
#include <stdexcept>

log_define("component.schedule")

// <%pre>
#line 1 "schedule.ecpp"


#include <livefeatures.h>
#include <setup.h>
#include <tools.h>
#include <epg_events.h>
#include <recman.h>


#include <vdr/config.h>
using namespace std;
using namespace vdrlive;

void addAllRecordings(list<RecordingsItemPtr> &RecItems, RecordingsTreePtr &RecordingsTree, vector<string> &P){
  for (RecordingsMap::iterator iter = RecordingsTree->begin(P); iter != RecordingsTree->end(P);  ++iter) {
        RecordingsItemPtr recItem = iter->second;
        if (!recItem->IsDir()) {
                RecItems.push_back(recItem);
        } else {
                vector<string> pp(P);
                pp.push_back(recItem->Name());
                addAllRecordings(RecItems, RecordingsTree, pp);
        }
  }
  RecItems.sort(RecordingsItemPtrCompare::ByAscendingName);
}

// compare function for std::lower_bound / std::upper_bound
bool compRecItemName(const RecordingsItemPtr &first, const RecordingsItemPtr &second) {
  return first->NameForCompare().compare(second->NameForCompare() ) < 0;
}

bool searchNameDesc(RecordingsItemPtr &RecItem, list<RecordingsItemPtr> &RecItems, const string &Name, const string &ShortText, const string &Description, long Duration) {
  if(RecItems.begin() == RecItems.end() ) return false;  // there are no recordings

// find all recordings with equal name
  RecordingsItemPtr dummy (new RecordingsItemDummy(Name, ShortText, Description, Duration));
  list<RecordingsItemPtr>::iterator recIterLowName = std::lower_bound (RecItems.begin(), RecItems.end(), dummy, compRecItemName);
  list<RecordingsItemPtr>::iterator recIterUpName  = std::upper_bound (recIterLowName  , RecItems.end(), dummy, compRecItemName);
  if ( recIterLowName == recIterUpName ) return false; // there is no recording with this name


// find all recordings with matching short text / description
  list<RecordingsItemPtr>::iterator recIterLow = std::lower_bound (recIterLowName, recIterUpName, dummy, RecordingsItemPtrCompare::ByAscendingName);
  list<RecordingsItemPtr>::iterator recIterUp = std::upper_bound (recIterLow, recIterUpName, dummy, RecordingsItemPtrCompare::ByAscendingName);

  if(recIterLow != recIterUp) {   // exact match found
    if (RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLow, recIterUp, dummy) > 0) return true;
    RecItem = *recIterLow;
    return true;
  }
// no exact match found, get recording with most matching characters
  int numEqualCharsLow = 0;
  int numEqualCharsUp  = 0;

  if(recIterLow != recIterLowName) { 
    --recIterLow;
    RecordingsItemPtrCompare::Compare2(numEqualCharsLow, *recIterLow, dummy);
  }
  if(recIterUp != recIterUpName)
    RecordingsItemPtrCompare::Compare2(numEqualCharsUp , *recIterUp , dummy);

  if ( numEqualCharsLow > numEqualCharsUp ) {
    if( numEqualCharsLow > 5 ) { RecItem = *recIterLow; return true; }
  } else {
    if( numEqualCharsUp  > 5 ) { RecItem = *recIterUp;  return true; }
  }


// no exact match found, get best match
  int num_match_rec = RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLowName, recIterUpName, dummy);
  if(num_match_rec == 0 || num_match_rec > 5) return false; // no matching lenght or series (too many matching length)
  return true;
}



#line 1 "page_init.eh"

// do not add to Makefile
// and do not write a ecpp comment into this file. It must produce no
// html output not even an empty line.
#include <tnt/savepoint.h>
#include <exception.h>

#line 2 "page_exit.eh"

#include <exception.h>

// </%pre>

namespace
{
class _component_ : public tnt::EcppComponent
{
    _component_& main()  { return *this; }

  protected:
    ~_component_();

  public:
    _component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl);

    unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    class channel_selection_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        channel_selection_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    class rec_item_file_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        rec_item_file_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    channel_selection_type channel_selection;
    rec_item_file_type rec_item_file;
};

static tnt::ComponentFactoryImpl<_component_> Factory("schedule");

static const char* rawData = "(\001\000\000L\001\000\000W\001\000\000Z\001\000\000n\001\000\000q\001\000\000\211\001"
  "\000\000\214\001\000\000\216\001\000\000\310\001\000\000\001\002\000\000M\002\000\000o\002\000\000\227\002\000\000"
  "\231\002\000\000\266\002\000\000\270\002\000\000\340\002\000\000\354\002\000\000\365\002\000\000\000\003\000\0006\003"
  "\000\000S\003\000\000U\003\000\000v\003\000\000\220\003\000\000\223\003\000\000\231\003\000\000\265\003\000\000\312"
  "\003\000\000\354\003\000\000\001\004\000\000\"\004\000\000(\004\000\000J\004\000\000P\004\000\000W\004\000\000X\004"
  "\000\000d\004\000\000~\004\000\000\177\004\000\000\200\004\000\000\335\004\000\000\367\004\000\000\014\005\000\000"
  "\022\005\000\000\030\005\000\000f\005\000\000\256\005\000\000\274\005\000\000\275\005\000\000\277\005\000\000\031\006"
  "\000\000\034\006\000\0006\006\000\000C\006\000\000R\006\000\000]\006\000\000\267\006\000\000\272\006\000\000\301\006"
  "\000\000\330\006\000\000\362\006\000\000\370\006\000\000$\007\000\000F\007\000\000[\007\000\000|\007\000\000\202\007"
  "\000\000\232\007\000\000\233\007\000\000\234\007\000\000\235\007\000\000\236\007\000\000\n<html>\n\t<head>\n\t\t<titl"
  "e>VDR Live - </title>\n\t\t\n\t\t\n\t</head>\n\t<body>\n\t\t\n\t\t\n\t\t<div class=\"inhalt\">\n\t\t\t.\n\t\t<table c"
  "lass=\"listing\" cellspacing=\"0\" cellpadding=\"0\">\n\t\t\t\t<tr class=\"spacer\">\n\t\t\t\t\t<td colspan=\"5\"/>\n"
  "\t\t\t\t</tr>\n\t\t\t\t<tr class=\"head\">\n\t\t\t\t\t<td colspan=\"5\"><div class=\"boxheader\"><div><div></div></di"
  "v></div></td>\n\t\t\t\t</tr>\n\t\t\t\t<tr>\n\t\t\t\t\t<td class=\"action leftcol \"></td>\n\t\t\t\t\t<td class=\"acti"
  "on \"><a href=\"searchresults.html\?searchplain=\"><img src=\"\" alt=\"\" ></img></a><img src=\"img/transparent.png\""
  " width=\"16\" height=\"16\"></td>\n\t\t\t\t\t<td class=\"action \"></td>\n\t\t\t\t\t<td class=\"topaligned \"><div cl"
  "ass=\"withmargin\"> - <br /></div></td>\n\t\t\t\t\t<td class=\" topaligned rightcol \"><div class=\"more withmargin\""
  "><a ><span class=\"title\"></span><br /><span class=\"short\">&nbsp;</span></a></div></td>\n\n\t\t\t\t</tr>\n<tr>\n "
  "\n</tr>\n\n\t\t\t</table>\n\t\t</div>\n\t</body>\n</html>\n\n\n<form action=\"schedule.html\" method=\"get\" id=\"cha"
  "nnels\">\n   <span>\n     <label for=\"channel\">:&nbsp;<span class=\"bold\"></span></label>\n     \n     \n     \n  "
  " </span>\n</form>\n<span class=\"sep\">|</span>\n<a href=\"schedule.html\?channel=\">\302\253 Prev</a>\n<span class="
  "\"sep\">|</span>\n<a href=\"schedule.html\?channel=\">Next \302\273</a>\n\n\n\n<td colspan=\"2\" style=\"word-wrap: n"
  "ormal;min-width: 10px;max-width: 70px;\" class=\"leftcol \">   </td>\n<td class=\"action \"> <img src=\"\" alt=\"on_d"
  "vd\"  /> </td>\n\n<td colspan=\"3\" style=\"word-wrap: normal;min-width: 10px;max-width: 70px;\" class=\"leftcol \"> "
  " </td>\n\n<td class=\"topaligned \"><div class=\"withmargin\"><br /></div></td>\n\n<td class=\"topaligned rightcol \""
  "><div class=\"more withmargin\"><a ><span class=\"title\"></span><br /><span class=\"short\">&nbsp;</span></a></div><"
  "/td>\n\n\n\n\n\n";

// <%shared>
// </%shared>

// <%config>
// </%config>

#define SET_LANG(lang) \
     do \
     { \
       request.setLang(lang); \
       reply.setLocale(request.getLocale()); \
     } while (false)

_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)
  : EcppComponent(ci, um, cl),
    channel_selection(*this, "channel_selection"),
    rec_item_file(*this, "rec_item_file")
{
  // <%init>
  // </%init>
}

_component_::~_component_()
{
  // <%cleanup>
  // </%cleanup>
}

unsigned _component_::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule " << qparam.getUrl());

  tnt::DataChunks data(rawData);

  // <%args>
int channel = qparam.has("channel") ? tnt::stringToWithDefault<int>(qparam.param("channel"), ( -1), reply.out().getloc()) : ( -1);
  // </%args>

#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_GLOBAL_VAR(logged_in_type, logged_in, "bool logged_in", (false));   // <%session> bool logged_in(false)
#line 85 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_PAGE_VAR(Channel_type, Channel, "cChannel* Channel", ());   // <%request> cChannel* Channel
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_GLOBAL_VAR(pageTitle_type, pageTitle, "std::string pageTitle", ());   // <%request> std::string pageTitle
  // <%cpp>
  // <%include> page_init.eh
#line 11 "page_init.eh"

try {
	reply.setHeader("Expires", "Mon, 26 Jul 1997 05:00:00 GMT");
	tnt::Savepoint spoint( reply );

  // </%include>
#line 88 "schedule.ecpp"

if (!logged_in && LiveSetup().UseAuth()) return reply.redirect("login.html");

#line 91 "schedule.ecpp"

	pageTitle = trVDR("Schedule");

vector<string> path;
list<RecordingsItemPtr> recItems;
RecordingsTreePtr recordingsTree(LiveRecordingsManager()->GetRecordingsTree());

addAllRecordings(recItems, recordingsTree, path);


#if VDRVERSNUM < 20301
	cSchedulesLock schedulesLock;
	cSchedules const* schedules = cSchedules::Schedules( schedulesLock );

	ReadLock channelsLock( Channels );
	if ( !channelsLock )
		throw HtmlError( tr("Couldn't aquire access to channels, please try again later.") );
#endif

	// cChannel* Channel; (see %request above)
	if ( channel > 0 ) {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
		Channel = (cChannel *)Channels->GetByNumber( channel );
#else
		Channel = Channels.GetByNumber( channel );
#endif
	}
	else {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
#endif
		if (cDevice::CurrentChannel()) {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->GetByNumber(cDevice::CurrentChannel());
#else
			Channel = Channels.GetByNumber(cDevice::CurrentChannel());
#endif
		}
		else {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->Get( Channels->GetNextNormal( -1 ) );
#else
			Channel = Channels.Get( Channels.GetNextNormal( -1 ) );
#endif
		}
	}
	if ( Channel == 0 )
		throw HtmlError( tr("Couldn't find channel or no channels available. Maybe you mistyped your request?") );

	cSchedule const* Schedule;
#if VDRVERSNUM >= 20301
	{
		LOCK_SCHEDULES_READ;
		Schedule = Schedules->GetSchedule( (const cChannel *)Channel );
	}
#else
	Schedule = schedules->GetSchedule( Channel );
#endif

  // <& pageelems.doc_type ...
  { 
#line 151 "schedule.ecpp"
    tnt::QueryParams _tnt_cq0;
#line 151 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "doc_type"), request, reply, _tnt_cq0);
    // &>
  }
  reply.out() << data[0]; // \n<html>\n\t<head>\n\t\t<title>VDR Live - 
#line 154 "schedule.ecpp"
  reply.sout() << ( pageTitle );
  reply.out() << data[1]; // </title>\n\t\t
  // <& pageelems.stylesheets ...
  { 
#line 155 "schedule.ecpp"
    tnt::QueryParams _tnt_cq1;
#line 155 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "stylesheets"), request, reply, _tnt_cq1);
    // &>
  }
  reply.out() << data[2]; // \n\t\t
  // <& pageelems.ajax_js ...
  { 
#line 156 "schedule.ecpp"
    tnt::QueryParams _tnt_cq2;
#line 156 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_js"), request, reply, _tnt_cq2);
    // &>
  }
  reply.out() << data[3]; // \n\t</head>\n\t<body>\n\t\t
  // <& pageelems.logo ...
  { 
#line 159 "schedule.ecpp"
    tnt::QueryParams _tnt_cq3;
#line 159 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "logo"), request, reply, _tnt_cq3);
    // &>
  }
  reply.out() << data[4]; // \n\t\t
  // <& menu ...
  { 
#line 160 "schedule.ecpp"
    tnt::QueryParams _tnt_cq4;
#line 160 "schedule.ecpp"
    _tnt_cq4.add( "active", tnt::toString(("schedule"), reply.out().getloc() ) );
#line 160 "schedule.ecpp"
    _tnt_cq4.add( "component", tnt::toString(("schedule.channel_selection"), reply.out().getloc() ) );
#line 160 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "menu"), request, reply, _tnt_cq4);
    // &>
  }
  reply.out() << data[5]; // \n\t\t<div class="inhalt">\n
#line 162 "schedule.ecpp"

	if ( Schedule == 0 ) {

  reply.out() << data[6]; // \t\t\t
#line 165 "schedule.ecpp"
  reply.sout() << ( tr("No schedules available for this channel") );
  reply.out() << data[7]; // .\n
#line 166 "schedule.ecpp"

	}
	else {

  reply.out() << data[8]; // \t\t<table class="listing" cellspacing="0" cellpadding="0">\n
#line 171 "schedule.ecpp"

		string current_day = "";
		const cEvent* PresentEvent = Schedule->GetPresentEvent();
		time_t now = time(NULL) - ::Setup.EPGLinger * 60;
                RecordingsItemPtr recItem;
                bool recItemFound;
#if VDRVERSNUM >= 20301
		for (const cEvent *Event = (cEvent *)Schedule->Events()->First(); Event; Event = (cEvent *)Schedule->Events()->Next(Event)) {
#else
		for (const cEvent *Event = Schedule->Events()->First(); Event; Event = Schedule->Events()->Next(Event)) {
#endif
			if (Event->EndTime() <= now && Event != PresentEvent)
				continue;

			EpgInfoPtr epgEvent = EpgEvents::CreateEpgInfo(Channel, Event);

			string title(epgEvent->Title());
			string short_description(epgEvent->ShortDescr());
			string description(epgEvent->LongDescr());
			string start(epgEvent->StartTime(tr("%I:%M %p")));
			string end(epgEvent->EndTime(tr("%I:%M %p")));
                        int durationMinutes = epgEvent->Duration() / 60;
                        string duration(durationMinutes < 0 ? "" : FormatDuration(tr("(%d:%02d)"), durationMinutes / 60, durationMinutes % 60));
			string day(epgEvent->StartTime(tr("%A, %b %d %Y")));
			string epgid = EpgEvents::EncodeDomId(Channel->GetChannelID(), Event->EventID());

			bool truncated = false;
			bool lastEventCurrentDay = false;

                        recItemFound = searchNameDesc(recItem, recItems, title, short_description, description, epgEvent->Duration() );
			{
#if VDRVERSNUM >= 20301
				cEvent* NextEvent = (cEvent *)Schedule->Events()->Next(Event);
#else
				cEvent* NextEvent = Schedule->Events()->Next(Event);
#endif
				if (!NextEvent) {
					lastEventCurrentDay = true;
				}
				else {
					string nday(NextEvent->StartTime() ? FormatDateTime(tr("%A, %b %d %Y"), NextEvent->StartTime()) : "");
					lastEventCurrentDay = (day != nday);
				}
			}

			if (current_day != day) {
				if (current_day != "") {

  reply.out() << data[9]; // \t\t\t\t<tr class="spacer">\n\t\t\t\t\t<td colspan="5"/>\n\t\t\t\t</tr>\n
#line 222 "schedule.ecpp"

				}

  reply.out() << data[10]; // \t\t\t\t<tr class="head">\n\t\t\t\t\t<td colspan="5"><div class="boxheader"><div><div>
#line 226 "schedule.ecpp"
  reply.sout() << ( day );
  reply.out() << data[11]; // </div></div></div></td>\n\t\t\t\t</tr>\n
#line 228 "schedule.ecpp"

				current_day = day;
			}

  reply.out() << data[12]; // \t\t\t\t<tr>\n\t\t\t\t\t<td class="action leftcol 
#line 233 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[13]; // ">
  // <& pageelems.event_timer ...
  { 
#line 233 "schedule.ecpp"
    tnt::QueryParams _tnt_cq5;
#line 233 "schedule.ecpp"
    _tnt_cq5.add( "epgid", tnt::toString((epgid), reply.out().getloc() ) );
#line 233 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "event_timer"), request, reply, _tnt_cq5);
    // &>
  }
  reply.out() << data[14]; // </td>\n\t\t\t\t\t<td class="action 
#line 234 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[15]; // ">
#line 234 "schedule.ecpp"
if (LiveFeatures<features::epgsearch>().Recent() ) { 
  reply.out() << data[16]; // <a href="searchresults.html\?searchplain=
#line 234 "schedule.ecpp"
  reply.sout() << ( StringUrlEncode(title) );
  reply.out() << data[17]; // "><img src="
#line 234 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "search.png") );
  reply.out() << data[18]; // " alt="" 
  // <& tooltip.hint ...
  { 
#line 234 "schedule.ecpp"
    tnt::QueryParams _tnt_cq6;
#line 234 "schedule.ecpp"
    _tnt_cq6.add( "text", tnt::toString((tr("Search for repeats.")), reply.out().getloc() ) );
#line 234 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq6);
    // &>
  }
  reply.out() << data[19]; // ></img></a>
#line 234 "schedule.ecpp"
 } else { 
  reply.out() << data[20]; // <img src="img/transparent.png" width="16" height="16">
#line 234 "schedule.ecpp"
 } 
  reply.out() << data[21]; // </td>\n\t\t\t\t\t<td class="action 
#line 235 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[22]; // ">
  // <& pageelems.imdb_info_href ...
  { 
#line 235 "schedule.ecpp"
    tnt::QueryParams _tnt_cq7;
#line 235 "schedule.ecpp"
    _tnt_cq7.add( "title", tnt::toString((title), reply.out().getloc() ) );
#line 235 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "imdb_info_href"), request, reply, _tnt_cq7);
    // &>
  }
  reply.out() << data[23]; // </td>\n\t\t\t\t\t<td class="topaligned 
#line 236 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[24]; // "><div class="withmargin">
#line 236 "schedule.ecpp"
  reply.sout() << ( start );
  reply.out() << data[25]; //  - 
#line 236 "schedule.ecpp"
  reply.sout() << ( end );
  reply.out() << data[26]; // <br />
#line 236 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << data[27]; // </div></td>\n\t\t\t\t\t<td class="
#line 237 "schedule.ecpp"
  if ( (Event == PresentEvent) )
    reply.sout() <<  "current" ;
  reply.out() << data[28]; //  topaligned rightcol 
#line 237 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[29]; // "><div class="more withmargin"><a 
  // <& tooltip.hint ...
  { 
#line 237 "schedule.ecpp"
    tnt::QueryParams _tnt_cq8;
#line 237 "schedule.ecpp"
    _tnt_cq8.add( "text", tnt::toString((StringEscapeAndBreak(StringWordTruncate(description, 300, truncated)) + "<br />" + tr("Click to view details.")), reply.out().getloc() ) );
#line 237 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq8);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 237 "schedule.ecpp"
    tnt::QueryParams _tnt_cq9;
#line 237 "schedule.ecpp"
    _tnt_cq9.add( "domId", tnt::toString((epgEvent->Id()), reply.out().getloc() ) );
#line 237 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq9);
    // &>
  }
  reply.out() << data[30]; // ><span class="title">
#line 237 "schedule.ecpp"
  reply.sout() << ( title );
  reply.out() << data[31]; // </span><br /><span class="short">
#line 237 "schedule.ecpp"
if (short_description.empty()) { 
  reply.out() << data[32]; // &nbsp;
#line 237 "schedule.ecpp"
 } 
#line 237 "schedule.ecpp"
  reply.sout() << ( short_description );
  reply.out() << data[33]; // </span></a></div></td>\n\n\t\t\t\t</tr>\n
#line 240 "schedule.ecpp"

if(recItemFound) {
                  string r_day(FormatDateTime(tr("%a,"), recItem->StartTime()));
                  string dayLen(lexical_cast<string, int>(r_day.length() - 1) + ".25em;");
                  string duration(recItem->Duration() < 0 ? "" : FormatDuration(tr("(%d:%02d)"), recItem->Duration() / 60, recItem->Duration() % 60));
                  string shortDescr(recItem->RecInfo()->ShortText() ? recItem->RecInfo()->ShortText() : "");
                  string r_description(recItem->RecInfo()->Description() ? recItem->RecInfo()->Description() : "");
                  string hint(tr("Click to view details."));
                  if (!shortDescr.empty()) hint = shortDescr + "<br />" + hint;
                  else if (!r_description.empty()) hint = r_description + "<br />" + hint;

  reply.out() << data[34]; // <tr>\n 
  // <& rec_item_file ...
  { 
#line 252 "schedule.ecpp"
    tnt::QueryParams _tnt_cq10;
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "archived", tnt::toString((RecordingsManager::GetArchiveDescr(recItem->Recording())), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "day", tnt::toString((r_day), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "dayLen", tnt::toString((dayLen), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "duration", tnt::toString((duration), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "hint", tnt::toString((hint), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "id", tnt::toString((recItem->Id()), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "lastEventCurrentDay", tnt::toString((lastEventCurrentDay), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "level", tnt::toString((recItem->Level()), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "name", tnt::toString((recItem->Name()), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "shortDescr", tnt::toString((shortDescr), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
    _tnt_cq10.add( "startTime", tnt::toString((recItem->StartTime()), reply.out().getloc() ) );
#line 252 "schedule.ecpp"
  main().rec_item_file(request, reply, _tnt_cq10);
    // &>
  }
  reply.out() << data[35]; // \n</tr>\n
#line 254 "schedule.ecpp"

}

  reply.out() << data[36]; // \n
#line 258 "schedule.ecpp"

		}

  reply.out() << data[37]; // \t\t\t</table>\n
#line 262 "schedule.ecpp"

	}

  reply.out() << data[38]; // \t\t</div>\n\t</body>\n</html>\n
  // <%include> page_exit.eh
  reply.out() << data[39]; // \n
#line 5 "page_exit.eh"

	spoint.commit();
} catch ( vdrlive::HtmlError const& ex ) {
	tnt::QueryParams param = qparam;
	param.add( "pageTitle", pageTitle );
	param.add( "errorMessage", ex.what() );
	callComp( "error", request, reply, param );
}

  // </%include>
  reply.out() << data[40]; // \n
  reply.out() << data[49]; // \n
  reply.out() << data[50]; // \n\n
  reply.out() << data[69]; // \n
  reply.out() << data[70]; // \n
  reply.out() << data[71]; // \n
  reply.out() << data[72]; // \n
  // <%/cpp>
  return HTTP_OK;
}

unsigned _component_::channel_selection_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::channel_selection " << qparam.getUrl());
  tnt::DataChunks data(rawData);
#line 85 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_PAGE_VAR(Channel_type, Channel, "cChannel* Channel", ());   // <%request> cChannel* Channel
#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_GLOBAL_VAR(logged_in_type, logged_in, "bool logged_in", (false));   // <%session> bool logged_in(false)
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_GLOBAL_VAR(pageTitle_type, pageTitle, "std::string pageTitle", ());   // <%request> std::string pageTitle
  // <%cpp>
  reply.out() << data[41]; // <form action="schedule.html" method="get" id="channels">\n   <span>\n     <label for="channel">
#line 273 "schedule.ecpp"
  reply.sout() << ( tr("Channel") );
  reply.out() << data[42]; // :&nbsp;<span class="bold">
#line 273 "schedule.ecpp"
  reply.sout() << ( std::to_string(Channel->Number()) );
  reply.out() << data[43]; // </span></label>\n     
  // <& channels_widget ...
  { 
#line 274 "schedule.ecpp"
    tnt::QueryParams _tnt_cq11;
#line 274 "schedule.ecpp"
    _tnt_cq11.add( "name", tnt::toString(("channel"), reply.out().getloc() ) );
#line 274 "schedule.ecpp"
    _tnt_cq11.add( "onchange", tnt::toString(("document.forms.channels.submit()"), reply.out().getloc() ) );
#line 274 "schedule.ecpp"
    _tnt_cq11.add( "selected", tnt::toString((Channel ? *Channel->GetChannelID().ToString() : ""), reply.out().getloc() ) );
#line 274 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "channels_widget"), request, reply, _tnt_cq11);
    // &>
  }
  reply.out() << data[44]; // \n     
  // <& pageelems.ajax_action_href ...
  { 
#line 275 "schedule.ecpp"
    tnt::QueryParams _tnt_cq12;
#line 275 "schedule.ecpp"
    _tnt_cq12.add( "action", tnt::toString("switch_channel", reply.out().getloc() ) );
#line 275 "schedule.ecpp"
    _tnt_cq12.add( "alt", tnt::toString("", reply.out().getloc() ) );
#line 275 "schedule.ecpp"
    _tnt_cq12.add( "image", tnt::toString("zap.png", reply.out().getloc() ) );
#line 275 "schedule.ecpp"
    _tnt_cq12.add( "param", tnt::toString((Channel->GetChannelID()), reply.out().getloc() ) );
#line 275 "schedule.ecpp"
    _tnt_cq12.add( "tip", tnt::toString((tr("Switch to this channel.")), reply.out().getloc() ) );
#line 275 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_action_href"), request, reply, _tnt_cq12);
    // &>
  }
  reply.out() << data[45]; // \n     
  // <& pageelems.m3u_playlist_channel ...
  { 
#line 276 "schedule.ecpp"
    tnt::QueryParams _tnt_cq13;
#line 276 "schedule.ecpp"
    _tnt_cq13.add( "channelId", tnt::toString((Channel->GetChannelID()), reply.out().getloc() ) );
#line 276 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "m3u_playlist_channel"), request, reply, _tnt_cq13);
    // &>
  }
  reply.out() << data[46]; // \n   </span>\n</form>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 280 "schedule.ecpp"
  reply.sout() << ( std::max(0, ((int)Channel->Number() - 1)) );
  reply.out() << data[47]; // ">\302\253 Prev</a>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 282 "schedule.ecpp"
  reply.sout() << ( (Channel->Number() + 1) );
  reply.out() << data[48]; // ">Next \302\273</a>\n
  // <%/cpp>
  return HTTP_OK;
}

unsigned _component_::rec_item_file_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::rec_item_file " << qparam.getUrl());
  tnt::DataChunks data(rawData);
  // <%args>
string name = tnt::stringTo<string>("name", "string", qparam.param("name"), reply.out().getloc());
int level = tnt::stringTo<int>("level", "int", qparam.param("level"), reply.out().getloc());
string id = tnt::stringTo<string>("id", "string", qparam.param("id"), reply.out().getloc());
string day = tnt::stringTo<string>("day", "string", qparam.param("day"), reply.out().getloc());
string dayLen = tnt::stringTo<string>("dayLen", "string", qparam.param("dayLen"), reply.out().getloc());
time_t startTime = tnt::stringTo<time_t>("startTime", "time_t", qparam.param("startTime"), reply.out().getloc());
string duration = tnt::stringTo<string>("duration", "string", qparam.param("duration"), reply.out().getloc());
string hint = tnt::stringTo<string>("hint", "string", qparam.param("hint"), reply.out().getloc());
string shortDescr = tnt::stringTo<string>("shortDescr", "string", qparam.param("shortDescr"), reply.out().getloc());
string archived = tnt::stringTo<string>("archived", "string", qparam.param("archived"), reply.out().getloc());
bool lastEventCurrentDay = tnt::stringTo<bool>("lastEventCurrentDay", "bool", qparam.param("lastEventCurrentDay"), reply.out().getloc());
  // </%args>

#line 85 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_PAGE_VAR(Channel_type, Channel, "cChannel* Channel", ());   // <%request> cChannel* Channel
#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_GLOBAL_VAR(logged_in_type, logged_in, "bool logged_in", (false));   // <%session> bool logged_in(false)
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_GLOBAL_VAR(pageTitle_type, pageTitle, "std::string pageTitle", ());   // <%request> std::string pageTitle
  // <%cpp>
#line 301 "schedule.ecpp"
 if (!archived.empty()) { 
  reply.out() << data[51]; // <td colspan="2" style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 302 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[52]; // "> 
#line 302 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << data[53]; //   </td>\n<td class="action 
#line 303 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[54]; // "> <img src="
#line 303 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "on_dvd.png") );
  reply.out() << data[55]; // " alt="on_dvd" 
  // <& tooltip.hint ...
  { 
#line 303 "schedule.ecpp"
    tnt::QueryParams _tnt_cq14;
#line 303 "schedule.ecpp"
    _tnt_cq14.add( "text", tnt::toString((archived), reply.out().getloc() ) );
#line 303 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq14);
    // &>
  }
  reply.out() << data[56]; //  /> </td>\n\n
#line 305 "schedule.ecpp"
 } else { 
  reply.out() << data[57]; // <td colspan="3" style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 306 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[58]; // "> 
#line 306 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << data[59]; //  </td>\n
#line 307 "schedule.ecpp"
 } 
  reply.out() << data[60]; // \n<td class="topaligned 
#line 309 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[61]; // "><div class="withmargin">
#line 309 "schedule.ecpp"
  reply.sout() << ( FormatDateTime(tr("%a,"), startTime) + string(" ") + FormatDateTime(tr("%b %d %y"), startTime) + string(" ") + FormatDateTime(tr("%I:%M %p"), startTime) );
  reply.out() << data[62]; // <br />
#line 309 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << data[63]; // </div></td>\n\n<td class="topaligned rightcol 
#line 311 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << data[64]; // "><div class="more withmargin"><a 
  // <& tooltip.hint ...
  { 
#line 311 "schedule.ecpp"
    tnt::QueryParams _tnt_cq15;
#line 311 "schedule.ecpp"
    _tnt_cq15.add( "text", tnt::toString((hint), reply.out().getloc() ) );
#line 311 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq15);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 311 "schedule.ecpp"
    tnt::QueryParams _tnt_cq16;
#line 311 "schedule.ecpp"
    _tnt_cq16.add( "domId", tnt::toString((id), reply.out().getloc() ) );
#line 311 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq16);
    // &>
  }
  reply.out() << data[65]; // ><span class="title">
#line 311 "schedule.ecpp"
  reply.sout() << ( name );
  reply.out() << data[66]; // </span><br /><span class="short">
#line 311 "schedule.ecpp"
if (shortDescr.empty()) { 
  reply.out() << data[67]; // &nbsp;
#line 311 "schedule.ecpp"
 } 
#line 311 "schedule.ecpp"
  reply.sout() << ( shortDescr );
  reply.out() << data[68]; // </span></a></div></td>\n\n
  // <%/cpp>
  return HTTP_OK;
}

} // namespace
